/*
    Custom Dialog

    Astun Technology
    Paul Porthouse
    14/07/2020

    Requirements:
        * None
*/

if (typeof Astun === "undefined") { Astun = {}; }
if (typeof Astun.JS === "undefined") { Astun.JS = {}; }

Astun.JS.CustomDialog = (function() {

    this.overlayElement = null;
    this.buttonElement = null;

    this.showOverlay = function() {
        this.overlayElement = this.createElement("div", "astun-custom-dialog-overlay");
        document.body.appendChild(this.overlayElement);
    };

    this.showDialog = function(title, content, buttonText) {
        // add a delay to the scroll as otherwise it may not work
        window.setTimeout(function() { window.scroll({ top: 0, left: 0, behavior: 'smooth'})}, 200);

        var titleElement = this.createElement("div", "astun-custom-dialog-title", { "id": "astun-custom-dialog-title" }, title);
        var contentElement = this.createElement("div", "astun-custom-dialog-content", { "id": "astun-custom-dialog-content" }, content);
        var buttonSpacerElement = this.createElement("div", "astun-custom-dialog-button-spacer", {});
        this.buttonElement = this.createElement("button", "astun-custom-dialog-button", {}, buttonText && buttonText !== "" ? buttonText : "Accept");
        var buttonFlexContainerElement = this.createElement("div", "astun-custom-dialog-button-flex-container", {}, null, [ buttonSpacerElement, this.buttonElement ]);
        var buttonContainerElement = this.createElement("div", "astun-custom-dialog-button-container", {}, null, [ buttonFlexContainerElement ]);
        var topWrapperSpacerElement = this.createElement("div", "astun-custom-dialog-wrapper-spacer top-spacer", {});
        var dialogElement = this.createElement(
            "div",
            "astun-custom-dialog", {
                "role": "dialog",
                "aria-modal": "true",
                "aria-labelledby": "astun-custom-dialog-title",
                "aria-describedby": "astun-custom-dialog-content"
            },
            null, [
                titleElement,
                contentElement,
                buttonContainerElement
            ]
        );
        var bottomWrapperSpacerElement = this.createElement("div", "astun-custom-dialog-wrapper-spacer bottom-spacer", {});
        var wrapperElement = this.createElement("div", "astun-custom-dialog-wrapper", {}, null, [ topWrapperSpacerElement, dialogElement, bottomWrapperSpacerElement ]);
        this.overlayElement = this.createElement("div", "astun-custom-dialog-overlay", {}, null, [ wrapperElement ]);

        this.buttonElement.addEventListener("click", this.removeDialog.bind(this));

        document.body.appendChild(this.overlayElement);

        document.body.className += " astun-custom-dialog-no-scroll";
    };

    this.removeDialog = function() {
        document.body.className = document.body.className.replace(/\sastun-custom-dialog-no-scroll/gi, "");

        this.overlayElement.parentElement.removeChild(this.overlayElement);
        this.buttonElement.removeEventListener("click", this.removeDialog);
        this.buttonElement = null;
        this.overlayElement = null;
    };

    this.createElement = function(elementName, classNames, attributes, value, childNodes) {
        var el = document.createElement(elementName);

        // add any classnames
        if (classNames) {
            el.className = classNames;
        }

        // add any attributes
        if (attributes) {
            for (var attribute in attributes) {
                if (!attributes.hasOwnProperty(attribute)) {
                    continue;
                }
                el.setAttribute(attribute, attributes[attribute]);
            }
        }

        // add any child nodes or a value (but not both)
        if (childNodes) {
            for (var index in childNodes) {
                var child = childNodes[index];
                if (!childNodes.hasOwnProperty(index)) {
                    continue;
                }
                el.appendChild(child);
            }
        } else if (value) {
            el.innerHTML = value;
        }

        return el;
    }

    return {
        "show": function(title, content, buttonText) {
            showDialog(title, content, buttonText);
        }
    };

})();
